@@ -1,6 +1,6 @@
 package Munin::Master::Logger;
 
-# $Id$
+=encoding utf-8
 
 =head1 NAME
 
@@ -59,6 +59,7 @@ use base qw(Exporter);
 use strict;
 use warnings;
 
+use Carp qw(confess);
 use English qw(-no_match_vars);
 use File::Basename qw(basename);
 use Log::Log4perl qw(:easy);
